@@ -141,8 +141,10 @@ def partitionOverlaps(
         kmer_list.append(lst[final_start_index:seq_len])
 
     # Test that last value was added on correctly
-
-    assert kmer_list[-1][-1] == lst[-1]
+    try:
+        assert kmer_list[-1][-1] == lst[-1]
+    except (AssertionError, IndexError) as e:
+        print(f"Error: Last k-mer does not match original sequence: {e}\n")
     return kmer_list
 
 
@@ -352,6 +354,9 @@ def selfContainmentMatrix(
     n = len(mod_set)
     progress_thresholds = round(n / 77)
 
+    if progress_thresholds == 0:
+        progress_thresholds = 1
+
     printProgressBar(0, n, prefix="Progress:", suffix="Complete", length=40)
     containment_matrix = np.empty((n, n))
 
@@ -410,6 +415,8 @@ def pairwiseContainmentMatrix(
     """
     n = max(len(mod_set_y), len(mod_set_x))
     progress_thresholds = round(n / 77)
+    if progress_thresholds == 0:
+        progress_thresholds = 1
 
     if not supress_progress:
         printProgressBar(0, n, prefix="Progress:", suffix="Complete", length=40)
